@@ -8,89 +8,89 @@ BibLaTeX_entry_field_db$Book <- c('author|editor|translator', 'title',
 
 # multivolume book
 BibLaTeX_entry_field_db$MVBook <- c('author|editor|translator', 'title',
-                                    'year|date')  
+                                    'year|date')
 
 # different from BibTeX
 BibLaTeX_entry_field_db$InBook <- c('author', 'title', 'booktitle|maintitle',
-                                    'year|date')  
+                                    'year|date')
 
 # e.g. book reprint in selected works of author
 BibLaTeX_entry_field_db$BookInBook <- c('author', 'title',
-                                        'booktitle|maintitle', 'year|date')  
+                                        'booktitle|maintitle', 'year|date')
 
 # supplemental material for book
 BibLaTeX_entry_field_db$SuppBook <- c('author', 'title', 'booktitle|maintitle',
-                                      'year|date')  
+                                      'year|date')
 
 # book without formal publisher
-BibLaTeX_entry_field_db$Booklet <- c('author|editor', 'title', 'year|date')  
+BibLaTeX_entry_field_db$Booklet <- c('author|editor', 'title', 'year|date')
 
 # single-volume work, with lots of separate individual works
-BibLaTeX_entry_field_db$Collection <- c('editor', 'title', 'year|date') 
+BibLaTeX_entry_field_db$Collection <- c('editor', 'title', 'year|date')
 
 # multi-volume collection
-BibLaTeX_entry_field_db$MVCollection <- c('editor', 'title', 'year|date') 
+BibLaTeX_entry_field_db$MVCollection <- c('editor', 'title', 'year|date')
 
 # contribution to a collection
-BibLaTeX_entry_field_db$InCollection <- c('author', 'editor', 'title',
-                                          'booktitle', 'year|date') 
+BibLaTeX_entry_field_db$InCollection <- c('author', 'title',
+                                          'booktitle', 'year|date')
 
 # supplement to a collection
-BibLaTeX_entry_field_db$SuppCollection <- c('author', 'editor', 'title',
-                                            'booktitle', 'year|date') 
+BibLaTeX_entry_field_db$SuppCollection <- c('author', 'title',
+                                            'booktitle', 'year|date')
 
 #manual
-BibLaTeX_entry_field_db$Manual <- c('author|editor', 'title', 'year|date') 
+BibLaTeX_entry_field_db$Manual <- c('author|editor', 'title', 'year|date')
 
 # misc
 BibLaTeX_entry_field_db$Misc <- character(0)
 
 # online
 BibLaTeX_entry_field_db$Online <- c('author|editor', 'title', 'year|date',
-                                    'url|eprinttype') 
+                                    'url|eprinttype')
 
 # patent
-BibLaTeX_entry_field_db$Patent <- c('author', 'title', 'number', 'year|date') 
+BibLaTeX_entry_field_db$Patent <- c('author', 'title', 'number', 'year|date')
 
 # periodical
-BibLaTeX_entry_field_db$Periodical <- c('editor', 'title', 'year|date') 
+BibLaTeX_entry_field_db$Periodical <- c('editor', 'title', 'year|date')
 
 ## supplement to periodical; alias for article in most styles;
 ##   e.g. regular columns, obituaries, letters to editor, etc.
-BibLaTeX_entry_field_db$SuppPeriodical <- c('editor', 'title', 'year|date') 
+BibLaTeX_entry_field_db$SuppPeriodical <- c('editor', 'title', 'year|date')
 
 # proceedings
-BibLaTeX_entry_field_db$Proceedings <- c('editor', 'title', 'year|date') 
+BibLaTeX_entry_field_db$Proceedings <- c('title', 'year|date')
 
 # multi-volume proceedings
-BibLaTeX_entry_field_db$MVProceedings <- c('editor', 'title', 'year|date') 
+BibLaTeX_entry_field_db$MVProceedings <- c('title', 'year|date')
 
 # inproceedings: an article in conference proceedings
-BibLaTeX_entry_field_db$InProceedings <- BibLaTeX_entry_field_db$Proceedings
+BibLaTeX_entry_field_db$InProceedings <- c('author', 'title', 'booktitle', 'year|date')
 
 ## reference: alias for collection for most styles; specific type of collection
 ##   e.g. encyclopedia or dictionary
-BibLaTeX_entry_field_db$Reference <- c('editor', 'title', 'year|date') 
+BibLaTeX_entry_field_db$Reference <- BibLaTeX_entry_field_db$Collection
 
-# multi-volume reference: alias for mvcollection for most styles; 
-BibLaTeX_entry_field_db$MVReference <- BibLaTeX_entry_field_db$Reference
+# multi-volume reference: alias for mvcollection for most styles;
+BibLaTeX_entry_field_db$MVReference <- BibLaTeX_entry_field_db$MVCollection
 
-# inreference: alias for incollection for most styles; 
-BibLaTeX_entry_field_db$InReference <- BibLaTeX_entry_field_db$Reference
+# inreference: alias for incollection for most styles;
+BibLaTeX_entry_field_db$InReference <- BibLaTeX_entry_field_db$InCollection
 
 # report: need to specify type field. replaces techreport
 BibLaTeX_entry_field_db$Report <- c('author', 'title', 'type', 'institution',
-                                    'year|date') 
+                                    'year|date')
 
 # set: special, see Section 3.11.5 of biblatex manual
 BibLaTeX_entry_field_db$Set <- c('entryset')
 
 # thesis: replaces 'mastersthesis' and 'phdthesis' types by adding 'type' field
 BibLaTeX_entry_field_db$Thesis <- c('author', 'title', 'type',
-                                    'institution', 'year|date')  
+                                    'institution', 'year|date')
 
 # unpublished
-BibLaTeX_entry_field_db$Unpublished <- c('author', 'title', 'year|date') 
+BibLaTeX_entry_field_db$Unpublished <- c('author', 'title', 'year|date')
 
 ## xdata. special containers for data to be enherited by other entries which
 ##   specify an 'xdata' field; see Section 3.11.6 of bibtex manual
@@ -139,16 +139,16 @@ BibLaTeX_entry_field_db$Video <- character(0)
 
 # BibTeX
 BibTeX_entry_field_db <- list(
-Article = c("author", "title", "journal", "year"),   
-Book = c("author|editor", "title", "publisher", "year"),         
+Article = c("author", "title", "journal", "year"),
+Book = c("author|editor", "title", "publisher", "year"),
 Booklet = "title",
-InBook = c("author|editor", "title", "chapter", "publisher",  "year"),         
-InCollection = c("author", "title", "booktitle", "publisher", "year"),     
-InProceedings = c("author", "title", "booktitle", "year"),     
+InBook = c("author|editor", "title", "chapter|pages", "publisher",  "year"),
+InCollection = c("author", "title", "booktitle", "publisher", "year"),
+InProceedings = c("author", "title", "booktitle", "year"),
 Manual = "title",
-MastersThesis = c("author", "title", "school", "year"),  
+MastersThesis = c("author", "title", "school", "year"),
 Misc = character(0),
-PhdThesis = c("author", "title",  "school", "year"),  
-Proceedings =  c("title", "year"), 
-TechReport = c("author", "title", "institution", "year"),       
+PhdThesis = c("author", "title",  "school", "year"),
+Proceedings =  c("title", "year"),
+TechReport = c("author", "title", "institution", "year"),
 Unpublished = c("author", "title",  "note"))
