@@ -36,10 +36,14 @@
 #' CrossRef; when \code{use.old.api = FALSE}, the query HTTP request is parsed to create
 #' the \code{BibEntry} object (i.e. there are less HTTP requests when using the new API).
 #'
-#' CrossRef assigns a score between 0 and 100 based on how relevant a reference seems
-#' to be to your query.  The \emph{old} API documentation warns that while false
-#' negatives are unlikely, the search can be prone to false positives.  Hence, setting
-#' \code{min.revelance} to a high value may be necessary if \code{use.old.api = TRUE}.
+#' CrossRef assigns a score between 0 and 100 based on how relevant a
+#' reference seems to be to your query.  The \emph{old} API
+#' documentation warns that while false negatives are unlikely, the
+#' search can be prone to false positives.  Hence, setting
+#' \code{min.revelance} to a high value may be necessary if
+#' \code{use.old.api = TRUE}. In some instances with the old API, no
+#' score is returned, if this happens, the entries are added with a
+#' message indicating that no score was available.
 #'
 #' Possible values for the \emph{names} in \code{filter} are \code{"has-funder"},
 #' \code{"funder"}, \code{"prefix"}, \code{"member"}, \code{"from-index-date"},
@@ -65,9 +69,9 @@
 #' package \code{rcrossref} for larger queries and deep paging
 #' @family pubmed
 #' @references Newer API: \url{https://github.com/CrossRef/rest-api-doc/blob/master/rest_api.md},
-#' Older API: \url{http://search.crossref.org/help/api}
+#' Older API: \url{https://search.crossref.org/help/api}
 #' @examples
-#' if (interactive() && !httr::http_error("http://search.crossref.org/")){
+#' if (interactive() && !httr::http_error("https://search.crossref.org/")){
 #'   BibOptions(check.entries = FALSE)
 #'   ## 3 results from the American Statistical Association involving "regression"
 #'   ReadCrossRef("regression", filter = list(prefix="10.1198"), limit = 3)
@@ -93,25 +97,27 @@ ReadCrossRef <- function(query = "", filter = list(), limit = 5, offset = 0,
                          delete.file = TRUE, verbose = FALSE,
                          use.old.api = FALSE){
   bad <- 0
-  
-  ## file.create(temp.file)
-  ## if query is valid doi, skip search and get BibTeX entry right away
 
+  ## file.create(temp.file)
+  if (delete.file)
+    on.exit(if (file.exists(temp.file)) unlink(temp.file, force = TRUE))
+
+  ## if query is valid doi, skip search and get BibTeX entry right away
   if (nzchar(.doi <- SearchDOIText(query))){
     num.res <- 1
-    bad <- GetCrossRefBibTeX(paste0("http://dx.doi.org/", .doi), temp.file)
+    bad <- GetCrossRefBibTeX(paste0("https://doi.org/", .doi), temp.file)
   }else{
     if (use.old.api){
       if (.is_not_nonempty_text(query))
           stop(gettextf("specify a valid %s", sQuote("query")))
 
-      results <- GET("http://search.crossref.org/dois",
+      results <- GET("https://search.crossref.org/dois",
                          query = list(q=query, year=year,
                          sort=sort, rows=limit))
     }else{
       params <- list(rows = limit, sort = sort, offset = offset)
       if (!.is_not_nonempty_text(query))
-        params$query <- query  
+        params$query <- query
 
       if (length(year))
           suppressWarnings(filter$"from-pub-date" <-
@@ -119,17 +125,17 @@ ReadCrossRef <- function(query = "", filter = list(), limit = 5, offset = 0,
 
       if (length(filter))
           params$filter <- paste(paste0(names(filter),":",filter),
-                                 collapse = ",")          
-      results <- GET("http://api.crossref.org/works", query=params)
+                                 collapse = ",")
+      results <- GET("https://api.crossref.org/works", query=params)
     }
     fromj <- content(results, type = "application/json", encoding = "UTF-8")
     if (http_error(results)){
       msg <- fromj$message[[1L]]
-      stop(gettextf("CrossRef API request failed [%s]: %s\n<%s>", 
+      stop(gettextf("CrossRef API request failed [%s]: %s\n<%s>",
                     status_code(results), msg$type,
                     msg$message), call. = FALSE)
     }
-    
+
     if (!use.old.api)
         fromj <- fromj$message$items
     num.res <- min(limit, length(fromj))
@@ -141,30 +147,39 @@ ReadCrossRef <- function(query = "", filter = list(), limit = 5, offset = 0,
     }
 
     if (num.res > 0L){
-        if (!use.old.api && is.na(.doi)){
+        if (verbose)
+            makeVerboseMessage <- function(name, score){
+                if (!is.null(score))
+                    gettextf("including the following entry %s%s:\n%s",
+                                     "with relevancy score ",
+                                     name,
+                                     score)
+                else
+                    gettextf("the following entry will be included, but its %s:\n%s",
+                                     "relevancy score was not available ",
+                                     name)
+            }
+        if (!use.old.api && !nzchar(.doi)){
           res <- lapply(fromj, ParseCrossRef)
-          good <- which(vapply(res, function(e){
-              good <- e$score >= min.relevance
+          good <- vapply(res, function(e){
+              good <- is.null(e$score) || e$score >= min.relevance
               if (good && verbose)
-                message(gettextf("including the following entry %s%s:\n%s",
-                                 "with relevancy score ",
-                                  e$title, e$score[[i]]))
+                message(makeVerboseMessage(e$title, e$score[[i]]))
+
               good
-          }, FALSE))
-          res <- res[good]
-          if (!length(res)){
+          }, FALSE)
+
+          if (!any(good)){
               message("no results with relavency score greater than ",
                       gettextf("%s successfully retrieved",
                            sQuote("min.relevance")))
             return()
           }
+
+          res <- res[good]
           class(res) <- c("BibEntry", "bibentry")
           return(res)
       }else{
-        file.create(temp.file)
-        if (delete.file)
-          on.exit(unlink(temp.file, force = TRUE))
-
         relevancies <- numeric(num.res)
         if (use.old.api){
             score.str <- "normalizedScore"
@@ -176,17 +191,16 @@ ReadCrossRef <- function(query = "", filter = list(), limit = 5, offset = 0,
             entry.str <- "title"
         }
         for(i in 1:num.res){
-          if (fromj[[i]][[score.str]] >= min.relevance){
-              bad <- bad + GetCrossRefBibTeX(paste0(if (!use.old.api)
-                                                        "http://dx.doi.org/",
-                                                    fromj[[i]][[doi.str]]),
-                                             temp.file)
-              if (verbose)
-                  message(gettextf("including the following entry %s%s:\n%s",
-                                   "with relevancy score ",
-                                   fromj[[i]][[entry.str]],
-                                   fromj[[i]][[score.str]]))
-              
+            score <- fromj[[i]][[score.str]]
+            doi.url <- fromj[[i]][[doi.str]]
+            if (!grepl("https?://(dx\\.)?doi.org/", doi.url))
+                doi.url <- paste0("https://doi.org/", doi.url)
+
+            if (is.null(score) || score >= min.relevance){
+                bad <- bad + GetCrossRefBibTeX(doi.url,
+                                               temp.file)
+                if (verbose)
+                    message(makeVerboseMessage(fromj[[i]][[entry.str]], score))
           }
         }
       }  # end else for old API processing
@@ -201,14 +215,14 @@ ReadCrossRef <- function(query = "", filter = list(), limit = 5, offset = 0,
   bib.res <- try(ReadBib(file=temp.file, .Encoding='UTF-8'), TRUE)
 
   bib.res$url <- vapply(bib.res$url, function(x) if (!is.null(x))
-                                                     URLdecode(x), "") 
+                                                     URLdecode(x), "")
   if (inherits(bib.res, "try-error"))
       stop(gettextf("failed to parse the returned BibTeX results; %s%s%s",
                     "if \'delete.file\' ",
                     "is FALSE, you can try viewing and editing the file: ",
                     temp.file))
 
-  return(bib.res)  
+  return(bib.res)
 }
 
 #' @keywords internal
