@@ -1,3 +1,7 @@
+## ----unload, include = FALSE---------------------------------------------
+## Needed to clear internal package citation list from previous vignette builds
+unloadNamespace("RefManageR")
+
 ## ----setup, include = TRUE, cache = FALSE--------------------------------
 library(RefManageR)
 bib <- ReadBib(system.file("Bib", "biblatexExamples.bib",
@@ -5,12 +9,6 @@ bib <- ReadBib(system.file("Bib", "biblatexExamples.bib",
 bib2 <- ReadBib(system.file("Bib", "RJC.bib", package = "RefManageR"))[[seq_len(20)]]
 BibOptions(check.entries = FALSE, style = "html")
 
-## ----fig.width=7, fig.height=6-------------------------------------------
-plot(cars)
-
-## ----fig.width=7, fig.height=6-------------------------------------------
-plot(cars)
-
 ## ----results = "asis", echo = FALSE--------------------------------------
 PrintBibliography(bib, .opts = list(check.entries = FALSE, bib.style = "draft"))
 
