@@ -9,7 +9,7 @@ test_that("ReadBib reads in 494 entries from RJC.bib", {
   expect_equal(length(bib), 494L)
 })
 
-test_that("ReadBib Ignores entry but does not stop with invalid author/editor", {
+test_that("ReadBib ignores entry but does not stop if invalid author/editor", {
   f <- file.path(system.file("Bib", "badFormat.bib", package = "RefManageR"))
   bib <- ReadBib(f, check = "error")
   expect_true(length(bib) == 1L)
